@@ -1,9 +1,7 @@
 import asyncio
 import sys
 import traceback
-from typing import Callable, Dict, Generator, Iterable, List, Optional, Set, Type, Union
-
-from graia.broadcast.entities.track_log import TrackLog, TrackLogType
+from typing import Callable, Dict, Iterable, List, Optional, Set, Type, Union
 
 from .builtin.event import ExceptionThrowed
 from .entities.decorator import Decorator
@@ -13,28 +11,16 @@ from .entities.exectarget import ExecTarget
 from .entities.listener import Listener
 from .entities.namespace import Namespace
 from .entities.signatures import Force, RemoveMe
-from .exceptions import (
-    DisabledNamespace,
-    ExecutionStop,
-    ExistedNamespace,
-    InvaildEventName,
-    PropagationCancelled,
-    RegisteredEventListener,
-    RequirementCrashed,
-    UnexistedNamespace,
-)
+from .entities.track_log import TrackLog, TrackLogType
+from .exceptions import (DisabledNamespace, ExecutionStop, ExistedNamespace,
+                         InvaildEventName, PropagationCancelled,
+                         RegisteredEventListener, RequirementCrashed,
+                         UnexistedNamespace)
 from .interfaces.decorator import DecoratorInterface
 from .interfaces.dispatcher import DispatcherInterface
 from .typing import T_Dispatcher
-from .utilles import (
-    Ctx,
-    argument_signature,
-    cached_isinstance,
-    dispatcher_mixin_handler,
-    group_dict,
-    printer,
-    run_always_await_safely,
-)
+from .utilles import (Ctx, argument_signature, dispatcher_mixin_handler,
+                      group_dict, printer, run_always_await_safely)
 
 
 class Broadcast:
@@ -102,7 +88,7 @@ class Broadcast:
         with self.event_ctx.use(event):
             for _, current_group in sorted(grouped.items(), key=lambda x: x[0]):
                 coros = [
-                    self.Executor(target=i, dispatchers=event_dispatcher_mixin)  # type: ignore
+                    self.Executor(target=i, dispatchers=event_dispatcher_mixin)
                     for i in current_group
                 ]
                 done_tasks, _ = await asyncio.wait(coros)
@@ -117,62 +103,44 @@ class Broadcast:
         post_exception_event: bool = True,
         print_exception: bool = True,
     ):
-        is_exectarget = cached_isinstance(target, ExecTarget)
-        is_listener = cached_isinstance(target, Listener)
-        event: Optional[Dispatchable] = self.event_ctx.get(None)
+        is_exectarget = is_listener = False
+        if isinstance(target, Listener):
+            is_exectarget = is_listener = True
+        elif isinstance(target, ExecTarget):
+            is_exectarget = True
+        event: Optional[Dispatchable] = self.event_ctx.get()
 
         if is_listener:
-            if target.namespace.disabled:  # type: ignore
+            if target.namespace.disabled:
                 raise DisabledNamespace(
-                    "catched a disabled namespace: {0}".format(target.namespace.name)  # type: ignore
+                    "catched a disabled namespace: {0}".format(target.namespace.name)
                 )
 
         target_callable = target.callable if is_exectarget else target
         parameter_compile_result = {}
 
+        dii = self.dispatcher_interface
         track_logs: TrackLog = TrackLog()
-        async with self.dispatcher_interface.start_execution(
+        self.dispatcher_interface.start_execution(
             [
                 *(dispatchers or []),
-                *(target.namespace.injected_dispatchers if is_listener else []),  # type: ignore
+                *(target.namespace.injected_dispatchers if is_listener else []),
                 *(target.inline_dispatchers if is_exectarget else []),
             ],
             track_logs,
-        ) as dii:
-            try:
-                await dii.exec_lifecycle("beforeExecution")
-                if is_exectarget:
-                    if target.maybe_failure:
-                        initial_path = dii.init_dispatch_path()
-                        for name, annotation, default in argument_signature(
-                            target_callable
-                        ):
-                            if (
-                                target.param_paths.setdefault(name, initial_path)
-                                is initial_path
-                            ):
-                                target.param_paths[name + "$set"] = set()
-                            parameter_compile_result[name] = await dii.lookup_param(
-                                name, annotation, default, target.param_paths[name]  # type: ignore
-                            )
-                    else:
-                        for name, annotation, default in argument_signature(
-                            target_callable
-                        ):
-                            parameter_compile_result[
-                                name
-                            ] = await dii.lookup_param_without_log(
-                                name, annotation, default, target.param_paths[name]  # type: ignore
-                            )
-
-                    for hl_d in target.decorators:
-                        await dii.lookup_by_directly(
-                            self.decorator_interface,
-                            "_bcc_headless_decorators",
-                            None,
-                            hl_d,
+        )
+        try:
+            await dii.exec_lifecycle("beforeExecution")
+            if is_exectarget:
+                if target.maybe_failure:
+                    initial_path = dii.init_dispatch_path()
+                    for name, annotation, default in argument_signature(
+                        target_callable
+                    ):
+                        target.param_paths.setdefault(name, initial_path)
+                        parameter_compile_result[name] = await dii.lookup_param(
+                            name, annotation, default, target.param_paths[name]
                         )
-
                 else:
                     for name, annotation, default in argument_signature(
                         target_callable
@@ -180,62 +148,61 @@ class Broadcast:
                         parameter_compile_result[
                             name
                         ] = await dii.lookup_param_without_log(
-                            name, annotation, default, target.param_paths[name]  # type: ignore
+                            name, annotation, default, target.param_paths[name]
                         )
+                for hl_d in target.decorators:
+                    await dii.lookup_by_directly(
+                        self.decorator_interface,
+                        "_bcc_headless_decorators",
+                        None,
+                        hl_d,
+                    )
+            else:
+                for name, annotation, default in argument_signature(target_callable):
+                    parameter_compile_result[name] = await dii.lookup_param_without_log(
+                        name, annotation, default, target.param_paths[name]
+                    )
+            await dii.exec_lifecycle("afterDispatch", None, None)
+            result = await run_always_await_safely(
+                target_callable, **parameter_compile_result
+            )
+        except (ExecutionStop, PropagationCancelled):
+            raise
+        except RequirementCrashed:
+            traceback.print_exc()
+            raise
+        except Exception as e:
+            if event is not None and event.__class__ is not ExceptionThrowed:
+                if print_exception:
+                    traceback.print_exc()
+                elif post_exception_event:
+                    self.postEvent(ExceptionThrowed(exception=e, event=event))
+            raise
+        finally:
+            _, exception, tb = sys.exc_info()
+            await dii.exec_lifecycle("afterExecution", exception, tb)
+            dii.clean()
+            if is_exectarget and not track_logs.fluent_success:
+                paths = target.param_paths
+                current_path: Optional[List["T_Dispatcher"]] = None
+                has_failures = set()
+                for log_type, *log in track_logs.log:
+                    if log_type is TrackLogType.LookupStart:
+                        current_path = paths[log[0]]
+                    elif log_type is TrackLogType.Continue:
+                        has_failures.add(log[0])
+                    elif log_type is TrackLogType.Result:
+                        current_path[0].append(log[1])
+                    elif log_type is TrackLogType.LookupEnd:
+                        current_path[0] = list(dict.fromkeys(current_path[0]))
+                target.maybe_failure.symmetric_difference_update(has_failures)
 
-                await dii.exec_lifecycle("afterDispatch", None, None)
-                result = await run_always_await_safely(
-                    target_callable, **parameter_compile_result
-                )
-
-            except (ExecutionStop, PropagationCancelled):
-                raise
-            except RequirementCrashed:
-                traceback.print_exc()
-                raise
-            except Exception as e:
-                if event is not None:
-                    if print_exception or event.__class__ is ExceptionThrowed:
-                        traceback.print_exc()
-                    if post_exception_event and event.__class__ is not ExceptionThrowed:
-                        self.postEvent(ExceptionThrowed(exception=e, event=event))
-                raise
-            finally:
-                _, exception, tb = sys.exc_info()
-                await dii.exec_lifecycle("afterExecution", exception, tb)
-
-                if is_exectarget and not track_logs.fluent_success:
-                    current_paths = target.param_paths
-                    current_path: Optional[List[List["T_Dispatcher"]]] = None
-                    current_path_set: Optional[Set["T_Dispatcher"]] = None
-                    has_failures: set = set()
-
-                    for log in track_logs.log:
-                        if log[0] is TrackLogType.LookupStart:
-                            current_path = current_paths[log[1]]  # type: ignore
-                            current_path_set = current_paths[log[1] + "$set"]  # type: ignore
-                        elif log[0] is TrackLogType.LookupEnd:
-                            current_path = None
-                        elif (
-                            current_path is not None
-                            and log[0] is TrackLogType.Result
-                            and log[2] not in current_path_set  # type: ignore
-                        ):
-                            current_path[0].append(log[2])  # type: ignore
-                            current_path_set.add(log[2])  # type: ignore
-                        elif log[0] is TrackLogType.Continue:
-                            has_failures.add(log[1])
-
-                    target.maybe_failure.symmetric_difference_update(has_failures)
-
-            if result.__class__ is Force:
-                return result.content
-            elif result.__class__ is RemoveMe:
-                if cached_isinstance(target, Listener):
-                    if target in self.listeners:
-                        self.listeners.pop(self.listeners.index(target))
-
-            return result
+        if result.__class__ is Force:
+            return result.content
+        elif result.__class__ is RemoveMe:
+            if is_listener and target in self.listeners:
+                self.listeners.remove(target)
+        return result
 
     def postEvent(self, event: Dispatchable):
         self.loop.create_task(
@@ -330,16 +297,16 @@ class Broadcast:
         self,
         event: Union[str, Type[Dispatchable]],
         priority: int = 16,
-        dispatchers: List[T_Dispatcher] = [],
+        dispatchers: List[T_Dispatcher] = None,
         namespace: Namespace = None,
-        decorators: List[Decorator] = [],
+        decorators: List[Decorator] = None,
     ):
-        if cached_isinstance(event, str):
+        if isinstance(event, str):
             _name = event
-            event = self.findEvent(event)  # type: ignore
+            event = self.findEvent(event)
             if not event:
                 raise InvaildEventName(_name + " is not vaild!")  # type: ignore
-        priority = (type(priority) == int) and priority or int(priority)  # 类型转换
+        priority = int(priority)
 
         def receiver_wrapper(callable_target):
             may_listener = self.getListener(callable_target)
@@ -348,17 +315,19 @@ class Broadcast:
                     Listener(
                         callable=callable_target,
                         namespace=namespace or self.getDefaultNamespace(),
-                        inline_dispatchers=dispatchers,  # type: ignore
+                        inline_dispatchers=dispatchers,
                         priority=priority,
-                        listening_events=[event],  # type: ignore
+                        listening_events=[event],
                         decorators=decorators,
                     )
                 )
             else:
                 if event not in may_listener.listening_events:
-                    may_listener.listening_events.append(event)  # type: ignore
+                    may_listener.listening_events.append(event)
                 else:
-                    raise RegisteredEventListener(event.__name__, "has been registered!")  # type: ignore
+                    raise RegisteredEventListener(
+                        event.__name__, "has been registered!"
+                    )
             return callable_target
 
         return receiver_wrapper
