@@ -1,13 +1,14 @@
 from dataclasses import dataclass, field
-from typing import List
+from typing import TYPE_CHECKING, List
 
-from .dispatcher import BaseDispatcher
+if TYPE_CHECKING:
+    from graia.broadcast.typing import T_Dispatcher
 
 
 @dataclass
 class Namespace:
     name: str
-    injected_dispatchers: List[BaseDispatcher] = field(default_factory=list)
+    injected_dispatchers: List["T_Dispatcher"] = field(default_factory=list)
 
     priority: int = 0
     default: bool = False
