@@ -1,36 +1,19 @@
-from itertools import chain
 from functools import lru_cache
-from typing import (
-    TYPE_CHECKING,
-    Any,
-    Dict,
-    Generic,
-    Iterable,
-    List,
-    Sequence,
-    TypeVar,
-)
+from itertools import chain
+from typing import TYPE_CHECKING, Any, Dict, Generic, Iterable, List, TypeVar
 
-from graia.broadcast.entities.context import (
-    LF_TEMPLATE,
-    ExecutionContext,
-    ParameterContext,
-)
-from graia.broadcast.entities.dispatcher import BaseDispatcher
-from graia.broadcast.entities.event import Dispatchable
-from graia.broadcast.entities.signatures import Force
-from graia.broadcast.entities.track_log import TrackLog, TrackLogType
-from graia.broadcast.exceptions import RequirementCrashed
-from graia.broadcast.typing import (
-    DEFAULT_LIFECYCLE_NAMES,
-    T_Dispatcher,
-    T_Dispatcher_Callable,
-)
-
-from ..utilles import cached_getattr, run_always_await_safely
+from ..entities.context import ExecutionContext, ParameterContext
+from ..entities.dispatcher import BaseDispatcher
+from ..entities.event import Dispatchable
+from ..entities.signatures import Force
+from ..entities.track_log import TrackLog, TrackLogType
+from ..exceptions import RequirementCrashed
+from ..typing import (DEFAULT_LIFECYCLE_NAMES, T_Dispatcher,
+                      T_Dispatcher_Callable)
+from ..utilles import run_always_await_safely
 
 if TYPE_CHECKING:
-    from graia.broadcast import Broadcast
+    from .. import Broadcast
 
 
 class EmptyEvent(Dispatchable):
@@ -42,7 +25,6 @@ class EmptyEvent(Dispatchable):
 
 T_Event = TypeVar("T_Event", bound=Dispatchable)
 
-
 LIFECYCLE_ABS = {
     BaseDispatcher.beforeExecution,
     BaseDispatcher.afterDispatch,
@@ -53,13 +35,13 @@ LIFECYCLE_ABS = {
 class DispatcherInterface(Generic[T_Event]):
     broadcast: "Broadcast"
 
-    execution_contexts: List["ExecutionContext"]
-    parameter_contexts: List["ParameterContext"]
+    execution_contexts: List[ExecutionContext]
+    parameter_contexts: List[ParameterContext]
 
     track_logs: List[TrackLog]
 
     @property
-    def track_log(self):
+    def track_log(self) -> TrackLog:
         return self.track_logs[-1]
 
     def dispatcher_pure_generator(self) -> Iterable[T_Dispatcher]:
@@ -75,29 +57,22 @@ class DispatcherInterface(Generic[T_Event]):
         result = {}
 
         for name in DEFAULT_LIFECYCLE_NAMES:
-            v = cached_getattr(dispatcher, name, None)
+            v = getattr(dispatcher, name, None)
             if v and v.__func__ not in LIFECYCLE_ABS:
                 result[name] = v
         return result
 
     def flush_lifecycle_refs(
         self,
-        dispatchers: Sequence["T_Dispatcher"] = None,
+        dispatchers: Iterable[T_Dispatcher],
     ):
         from graia.broadcast.entities.dispatcher import BaseDispatcher
 
         lifecycle_refs = self.execution_contexts[-1].lifecycle_refs
-        if dispatchers is None and lifecycle_refs != LF_TEMPLATE:
-            return
 
-        for dispatcher in dispatchers or chain(
-            self.execution_contexts[0].dispatchers,
-            self.parameter_contexts[-1].dispatchers,
-            self.execution_contexts[-1].dispatchers,
-        ):
-            if (
-                not isinstance(dispatcher, BaseDispatcher)
-                and dispatcher.__class__ is not type
+        for dispatcher in dispatchers:
+            if dispatcher.__class__ is not type and not isinstance(
+                dispatcher, BaseDispatcher
             ):
                 continue
 
@@ -112,18 +87,18 @@ class DispatcherInterface(Generic[T_Event]):
             for func in lifecycle_funcs:
                 await run_always_await_safely(func, self, *args, **kwargs)
 
-    def inject_local_raw(self, *dispatchers: "T_Dispatcher"):
+    def inject_local_raw(self, *dispatchers: T_Dispatcher):
         # 为什么没有 flush: 因为这里的 lifecycle 是无意义的, 不会被 exec.
         for dispatcher in dispatchers[::-1]:
             self.parameter_contexts[-1].dispatchers.insert(0, dispatcher)
 
-    def inject_execution_raw(self, *dispatchers: "T_Dispatcher"):
+    def inject_execution_raw(self, *dispatchers: T_Dispatcher):
         for dispatcher in dispatchers:
             self.execution_contexts[-1].dispatchers.insert(0, dispatcher)
 
         self.flush_lifecycle_refs(dispatchers)
 
-    def inject_global_raw(self, *dispatchers: "T_Dispatcher"):
+    def inject_global_raw(self, *dispatchers: T_Dispatcher):
         # self.dispatchers.extend(dispatchers)
         for dispatcher in dispatchers[::-1]:
             self.execution_contexts[0].dispatchers.insert(1, dispatcher)
@@ -142,10 +117,6 @@ class DispatcherInterface(Generic[T_Event]):
     def default(self) -> Any:
         return self.parameter_contexts[-1].default
 
-    @property
-    def _index(self) -> int:
-        return self.execution_contexts[-1]._index
-
     @property
     def event(self) -> T_Event:
         return self.broadcast.event_ctx.get()  # type: ignore
@@ -182,38 +153,26 @@ class DispatcherInterface(Generic[T_Event]):
         ]
         self.track_logs = [TrackLog()]
 
-    async def __aenter__(self) -> "DispatcherInterface":
-        return self
-
-    async def __aexit__(self, _, exc: Exception, tb):
+    def clean(self):
         self.execution_contexts.pop()
         self.track_logs.pop()
-        if tb is not None:
-            raise exc.with_traceback(tb)
 
     def start_execution(
         self,
         dispatchers: List[T_Dispatcher],
         track_log_receiver: TrackLog,
-    ) -> "DispatcherInterface":
+    ):
         self.execution_contexts.append(ExecutionContext(dispatchers))
         self.track_logs.append(track_log_receiver)
-        self.flush_lifecycle_refs()
+        self.flush_lifecycle_refs(self.dispatcher_pure_generator())
         return self
 
     @staticmethod
     @lru_cache(maxsize=None)
     def dispatcher_callable_detector(dispatcher: T_Dispatcher) -> T_Dispatcher_Callable:
-        # 没人有兴趣玩魔法吧..
-        # 这里之前判定了下 dispatcher is class......是 staticmethod 检查啊.
-        if hasattr(dispatcher, "catch"):
-            return dispatcher.catch  # type: ignore
-        elif callable(dispatcher):
-            return dispatcher
-        else:
-            raise ValueError("invaild dispatcher: ", dispatcher)
+        return getattr(dispatcher, "catch", dispatcher)  # type: ignore
 
-    def init_dispatch_path(self) -> List[List["T_Dispatcher"]]:
+    def init_dispatch_path(self) -> List[List[T_Dispatcher]]:
         return [
             [],
             self.execution_contexts[0].dispatchers,
@@ -226,7 +185,7 @@ class DispatcherInterface(Generic[T_Event]):
         name: str,
         annotation: Any,
         default: Any,
-        using_path: List[List["T_Dispatcher"]] = None,
+        using_path: List[List[T_Dispatcher]] = None,
     ) -> Any:
         self.parameter_contexts.append(
             ParameterContext(
@@ -234,20 +193,16 @@ class DispatcherInterface(Generic[T_Event]):
             )
         )
 
-        result = None
         try:
             for dispatcher in self.current_path:
-                result = await run_always_await_safely(
-                    self.dispatcher_callable_detector(dispatcher), self
-                )
+                result = await self.dispatcher_callable_detector(dispatcher)(self)
 
                 if result is None:
                     continue
 
                 if result.__class__ is Force:
-                    result = result.target
+                    return result.target
 
-                self.execution_contexts[-1]._index = 0
                 return result
             else:
                 raise RequirementCrashed(
@@ -264,7 +219,7 @@ class DispatcherInterface(Generic[T_Event]):
         name: str,
         annotation: Any,
         default: Any,
-        using_path: List[List["T_Dispatcher"]] = None,
+        using_path: List[List[T_Dispatcher]] = None,
     ) -> Any:
         self.parameter_contexts.append(
             ParameterContext(
@@ -276,9 +231,7 @@ class DispatcherInterface(Generic[T_Event]):
         track_log.append((TrackLogType.LookupStart, name, annotation, default))
         try:
             for dispatcher in self.current_path:
-                result = await run_always_await_safely(
-                    self.dispatcher_callable_detector(dispatcher), self
-                )
+                result = await self.dispatcher_callable_detector(dispatcher)(self)
 
                 if result is None:
                     self.track_log.fluent_success = False
@@ -286,10 +239,9 @@ class DispatcherInterface(Generic[T_Event]):
                     continue
 
                 if result.__class__ is Force:
-                    result = result.target
+                    return result.target
 
                 track_log.append((TrackLogType.Result, name, dispatcher))
-                self.execution_contexts[-1]._index = 0
                 return result
             else:
                 track_log.append((TrackLogType.RequirementCrashed, name))
@@ -304,18 +256,14 @@ class DispatcherInterface(Generic[T_Event]):
             self.parameter_contexts.pop()
 
     async def lookup_using_current(self) -> Any:
-        result = None
         for dispatcher in self.current_path:
-            result = await run_always_await_safely(
-                self.dispatcher_callable_detector(dispatcher), self
-            )
+            result = await self.dispatcher_callable_detector(dispatcher)(self)
             if result is None:
                 continue
 
             if result.__class__ is Force:
-                result = result.target
+                return result.target
 
-            self.execution_contexts[-1]._index = 0
             return result
         else:
             raise RequirementCrashed(
@@ -331,7 +279,7 @@ class DispatcherInterface(Generic[T_Event]):
         name: str,
         annotation: Any,
         default: Any,
-        using_path: List[List["T_Dispatcher"]] = None,
+        using_path: List[List[T_Dispatcher]] = None,
     ) -> Any:
         self.parameter_contexts.append(
             ParameterContext(
@@ -342,7 +290,7 @@ class DispatcherInterface(Generic[T_Event]):
         dispatcher_callable = self.dispatcher_callable_detector(dispatcher)
 
         try:
-            result = await run_always_await_safely(dispatcher_callable, self)
+            result = await dispatcher_callable(self)
             if result.__class__ is Force:
                 return result.target
 
