@@ -2,7 +2,8 @@ import inspect
 from contextlib import contextmanager
 from contextvars import ContextVar, Token
 from functools import lru_cache
-from typing import Any, Awaitable, Callable, Generic, Iterable, Type, TypeVar, Union
+from typing import (Any, Awaitable, Callable, Generic, Iterable, Type, TypeVar,
+                    Union)
 
 from .entities.dispatcher import BaseDispatcher
 
@@ -46,7 +47,7 @@ class Ctx(Generic[T]):
         self.reset(token)
 
 
-def printer(value):
+def printer(value: Any):
     print(value)
     return value
 
@@ -62,21 +63,18 @@ def group_dict(iterable: Iterable, key_callable: Callable[[Any], Any]):
 
 cache_size = 4096
 
-origin_isinstance = isinstance
-
-cached_isinstance = lru_cache(1024)(isinstance)
-cached_getattr = lru_cache(cache_size)(getattr)
-
 
 @lru_cache(cache_size)
-def argument_signature(callable_target):
+def argument_signature(callable_target: Callable):
     return [
         (
             name,
-            param.annotation if param.annotation != inspect._empty else None,  # type: ignore
-            param.default if param.default != inspect._empty else None,  # type: ignore
+            param.annotation
+            if param.annotation is not inspect.Signature.empty
+            else None,
+            param.default if param.default is not inspect.Signature.empty else None,
         )
-        for name, param in dict(inspect.signature(callable_target).parameters).items()
+        for name, param in inspect.signature(callable_target).parameters.items()
     ]
 
 
@@ -108,5 +106,5 @@ def dispatcher_mixin_handler(dispatcher: Union[Type[BaseDispatcher], BaseDispatc
     return result
 
 
-## NestableIterable impl migrated to:
-## > https://gist.github.com/GreyElaina/f9a5f998ec1c3fc7bddb811ce046d0ca
+# NestableIterable impl migrated to:
+# > https://gist.github.com/GreyElaina/f9a5f998ec1c3fc7bddb811ce046d0ca
